Handler<T extends IExpiration> class abstract

Implemented types
Implementers
Annotations
  • @includeInBarrelFile

Constructors

Handler(InputHandler<T> input)

Properties

algorithm CryptoAlgorithm
The cryptographic algorithm associated with this object.
no setteroverride
crypts List<T>
List of active crypt objects.
no setteroverride
currentCrypt → T
The current active crypt object.
no setteroverride
expirationDate DateTime?
The expiration date, or null if not set.
no setteroverride
expirationTimes int?
Maximum number of allowed usages before expiration.
no setteroverride
expirationTimesRemaining int?
Remaining number of allowed usages.
no setteroverride
expiredCrypts List<T>
List of expired crypt objects.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
maxCrypts int
final
maxDaysExpiredCrypts int?
final
maxExpiredCrypts int?
final
protectedCrypts List<T>
final
protectedExpiredCrypts List<T>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cleanCrypts() → void
Protected method to clear all crypts and expired crypts
deleteCrypt(String key) → void
Deletes a crypt object by key.
inherited
incrementUse() → void
Increments the usage counter for expiration times.
override
isExpired() bool
Returns true if the object is expired.
override
limitExpiredCrypts() → void
Limita il numero di expired crypts a maxExpiredCrypts
nextCrypt() → void
Advances to the next crypt object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeOldExpiredCrypts() → void
Rimuove da protectedExpiredCrypts quelli che superano maxDaysExpiredCrypts
setNextCrypt(T obj) → void
Sets the next crypt object in the chain.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited