InputHandler<T extends IExpiration> class

Input parameters for Handler constructor.

Annotations
  • @immutable

Constructors

InputHandler({required T initialCrypt, required int maxCrypts, int? maxExpiredCrypts, int? maxDaysExpiredCrypts})
const

Properties

hashCode int
The hash code for this object.
no setteroverride
initialCrypt → T
final
maxCrypts int
final
maxDaysExpiredCrypts int?
final
maxExpiredCrypts int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override