InputECDHKeyExchange class

Input parameters for ECDHKeyExchange constructor.

Annotations
  • @immutable

Constructors

InputECDHKeyExchange({required InputKeyExchangeBase parent, required String publicKey, required String privateKey, required String curve})
const

Properties

curve String
final
hashCode int
The hash code for this object.
no setteroverride
parent InputKeyExchangeBase
final
privateKey String
final
publicKey String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override