InputAsymmetricCipher class
Input parameters for AsymmetricCipher constructor.
- Annotations
-
- @immutable
Constructors
- InputAsymmetricCipher({required InputCipher parent, required String publicKey, String? privateKey})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- parent → InputCipher
-
final
- privateKey → String?
-
final
- publicKey → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override