InputAsymmetricSign class

Input parameters for AsymmetricSign constructor.

Annotations
  • @immutable

Constructors

InputAsymmetricSign({required InputSign parent, required String publicKey, String? privateKey})
const

Properties

hashCode int
The hash code for this object.
no setteroverride
parent InputSign
final
privateKey String?
final
publicKey String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override