InputKeyExchangeBase class

Input parameters for KeyExchangeBase constructor.

Annotations
  • @immutable

Constructors

InputKeyExchangeBase({required KeyExchangeAlgorithm algorithm, DateTime? expirationDate, int? expirationTimes})
const

Properties

algorithm KeyExchangeAlgorithm
final
expirationDate DateTime?
final
expirationTimes int?
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override