KeyExchangeBase class

Base class for key exchange implementations with expiration logic. Implements IBaseExpiration and manages expiration date, usage limits, and key exchange algorithm.

Implemented types
Implementers
Annotations
  • @includeInBarrelFile

Constructors

KeyExchangeBase(InputKeyExchangeBase input)
Constructs a KeyExchangeBase with the given input parameters.

Properties

algorithm KeyExchangeAlgorithm
Returns the key exchange algorithm for this implementation.
no setter
expirationDate DateTime?
Returns the expiration date, if any.
no setteroverride
expirationTimes int?
Returns the initial expiration times limit, if any.
no setteroverride
expirationTimesRemaining int?
Returns the remaining expiration times, if any.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

incrementUse() → void
isExpired() bool
Returns true if the object is expired.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited