InputChaCha20Cipher class
Input parameters for ChaCha20Cipher constructor.
- Annotations
-
- @immutable
Constructors
- InputChaCha20Cipher({required InputSymmetricCipher parent, required Uint8List nonce})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- nonce → Uint8List
-
final
- parent → InputSymmetricCipher
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override