KeyPair class

An asymmetric key pair (public and private keys).

Annotations
  • @immutable

Constructors

KeyPair({required String publicKey, required String privateKey})
const

Properties

hashCode int
The hash code for this object.
no setteroverride
privateKey String
final
publicKey String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override