IBaseExpiration class abstract

Base interface for expiration logic in cryptographic objects. Provides expiration date and usage limits.

Implementers
Annotations
  • @includeInBarrelFile

Constructors

IBaseExpiration()

Properties

expirationDate DateTime?
The expiration date, or null if not set.
no setter
expirationTimes int?
Maximum number of allowed usages before expiration.
no setter
expirationTimesRemaining int?
Remaining number of allowed usages.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isExpired() bool
Returns true if the object is expired.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited