IHandlerAsymmetric<T extends IAsymmetric> class
abstract
Handler for asymmetric cryptographic objects.
- Implemented types
- Implementers
Constructors
Properties
- algorithm → CryptoAlgorithm
-
The cryptographic algorithm associated with this object.
no setterinherited
-
crypts
→ List<
T> -
List of active crypt objects.
no setterinherited
- currentCrypt → T
-
The current active crypt object.
no setteroverride
- expirationDate → DateTime?
-
The expiration date, or null if not set.
no setterinherited
- expirationTimes → int?
-
Maximum number of allowed usages before expiration.
no setterinherited
- expirationTimesRemaining → int?
-
Remaining number of allowed usages.
no setterinherited
-
expiredCrypts
→ List<
T> -
List of expired crypt objects.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- keyId → Digest
-
Returns the SHA-256 hash of the key material as a hex string.
no setterinherited
- privateKey → String?
-
The private key as a string (optional).
no setterinherited
- publicKey → String
-
The public key as a string.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deleteCrypt(
String key) → void -
Deletes a crypt object by key.
inherited
-
incrementUse(
) → void -
Increments the usage counter for expiration times.
inherited
-
isExpired(
) → bool -
Returns true if the object is expired.
inherited
-
nextCrypt(
) → void -
Advances to the next crypt object.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setNextCrypt(
T obj) → void -
Sets the next crypt object in the chain.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited