Interface that declares the keyId. Returns SHA-256 hash of the key material as a hex string.
- Inheritance
-
- Object
- IBaseExpiration
- IExpiration
- IKeyId
- Implementers
- Annotations
-
- @includeInBarrelFile
Properties
- algorithm → CryptoAlgorithm
-
The cryptographic algorithm associated with this object.
no setterinherited
- expirationDate → DateTime?
-
The expiration date, or null if not set.
no setterinherited
- expirationTimes → int?
-
Maximum number of allowed usages before expiration.
no setterinherited
- expirationTimesRemaining → int?
-
Remaining number of allowed usages.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- keyId → Digest
-
Returns the SHA-256 hash of the key material as a hex string.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
incrementUse(
) → void -
Increments the usage counter for expiration times.
inherited
-
isExpired(
) → bool -
Returns true if the object is expired.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited