CryptoPeerCapabilities class

Represents the capability set of a cryptographic peer.

Annotations
  • @immutable

Constructors

CryptoPeerCapabilities({required List<KeyExchangeAlgorithm> keyExchange, required List<CryptoAlgorithm> asymmetric, required List<CryptoAlgorithm> symmetric, required String peerId})
const

Properties

asymmetric List<CryptoAlgorithm>
final
hashCode int
The hash code for this object.
no setteroverride
keyExchange List<KeyExchangeAlgorithm>
final
peerId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
symmetric List<CryptoAlgorithm>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override