validateNegotiation abstract method
Validates that the negotiated algorithms are supported and secure.
Implementation
bool validateNegotiation(NegotiationResult negotiation);
Validates that the negotiated algorithms are supported and secure.
bool validateNegotiation(NegotiationResult negotiation);