ICryptoSession class abstract
Interface for managing cryptographic sessions between peers.
- Implementers
- Annotations
-
- @includeInBarrelFile
Constructors
Properties
- currentSession → SecureSession?
-
Gets the current session if established.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
closeSession(
) → Future< void> - Closes the current session and cleans up resources.
-
completeSession(
) → Future< SecureSession> - Completes the session establishment process. Called by the responder after sending the response.
-
finalizeSession(
Map< String, dynamic> responseMessage) → Future<SecureSession> - Finalizes the session establishment process. Called by the initiator after receiving the response.
-
initiateSession(
CryptoPeerCapabilities localCapabilities) → Future< Map< String, dynamic> > - Initiates a session establishment process with remote peer. Returns the handshake message to send to the remote peer.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
respondToSession(
Map< String, dynamic> initiationMessage, CryptoPeerCapabilities localCapabilities) → Future<Map< String, dynamic> > - Responds to a session initiation from a remote peer. Returns the response message to send back.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited