IKeyExchange class abstract
Interface for key exchange protocols like ECDH.
- Implemented types
- Implementers
- Annotations
-
- @includeInBarrelFile
Constructors
Properties
- algorithm → KeyExchangeAlgorithm
-
The key exchange algorithm used by this implementation.
no setter
- expirationDate → DateTime?
-
The expiration date, or null if not set.
no setterinherited
- expirationTimes → int?
-
Maximum number of allowed usages before expiration.
no setterinherited
- expirationTimesRemaining → int?
-
Remaining number of allowed usages.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- privateKey → String
-
The private key used for generating shared secrets.
no setter
- publicKey → String
-
The public key that can be shared with the other party.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
- Generates a shared secret using the other party's public key. Returns the shared secret as hex string.
-
getPublicKey(
) → String - Returns the public key for sharing with the other party.
-
isExpired(
) → bool -
Returns true if the object is expired.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited