publicKey property
String
get
publicKey
The public key that can be shared with the other party.
Implementation
String get publicKey;
The public key that can be shared with the other party.
String get publicKey;