ECCKeyUtils class
Utilities for ECC key operations.
- Annotations
-
- @includeInBarrelFile
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
generateKeyPair(
{String curve = secp256r1}) → Future< Map< String, String> > - Generates an ECC key pair for the specified curve
-
parseKeyPair(
{required String publicKey, String? privateKey}) → ({ECPrivateKey? privateKey, ECPublicKey publicKey}) - Parses both public and private keys
-
parsePrivateKey(
String pemKey) → ECPrivateKey - Parses ECC private key from PEM string
-
parsePublicKey(
String pemKey) → ECPublicKey - Parses ECC public key from PEM string
-
performECDH(
ECPrivateKey privateKey, ECPublicKey publicKey) → Uint8List - Performs ECDH key agreement