KeyEncodingUtils class
Utilities for key encoding and conversion.
- Annotations
-
- @includeInBarrelFile
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
bytesToHex(
List< int> bytes) → String - Converts bytes to hex string
-
hexToBytes(
String hex) → Uint8List - Converts hex string to bytes
-
stringKeyToBytes(
String key) → Uint8List - Converts string key to bytes (for symmetric keys stored as strings)