RSAKeyUtils class

Utilities for RSA key operations.

Annotations
  • @includeInBarrelFile

Constructors

RSAKeyUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generateKeyPair({int bitLength = 2048}) Future<Map<String, String>>
Generates an RSA key pair in PEM format
parseKeyPair({required String publicKey, String? privateKey}) → ({RSAPrivateKey? privateKey, RSAPublicKey publicKey})
Parses both public and private keys (if provided)
parsePrivateKey(String pemKey) → RSAPrivateKey
Parses RSA private key from PEM string
parsePublicKey(String pemKey) → RSAPublicKey
Parses RSA public key from PEM string