SecureRandomUtils class

Utilities for SecureRandom generation.

Annotations
  • @includeInBarrelFile

Constructors

SecureRandomUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createSeeded({int seedLength = 32}) → SecureRandom
Creates and seeds a SecureRandom instance
generateRandomBytes(int length) Uint8List
Generates random bytes of specified length