ECDHKeyExchange class
ECDH key exchange implementation
- Inheritance
-
- Object
- KeyExchangeBase
- ECDHKeyExchange
- Implemented types
- Annotations
-
- @includeInBarrelFile
Constructors
Properties
- algorithm → KeyExchangeAlgorithm
-
Returns the key exchange algorithm for this implementation.
no setterinherited
- curve → String
-
The curve used for this key exchange
no setter
- expirationDate → DateTime?
-
Returns the expiration date, if any.
no setterinherited
- expirationTimes → int?
-
Returns the initial expiration times limit, if any.
no setterinherited
- expirationTimesRemaining → int?
-
Returns the remaining expiration times, if any.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- privateKey → String
-
The private key used for generating shared secrets.
no setteroverride
- publicKey → String
-
The public key that can be shared with the other party.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
Generates a shared secret using the other party's public key.
Returns the shared secret as hex string.
override
-
getPublicKey(
) → String -
Returns the public key for sharing with the other party.
override
-
incrementUse(
) → void -
inherited
-
isExpired(
) → bool -
Returns true if the object is expired.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFull(
InputECDHKeyExchange input) → ECDHKeyExchange - Creates an ECDHKeyExchange with full control over all parameters.
-
generateKeyPair(
{String curve = ECCKeyUtils.secp256r1}) → Future< Map< String, String> > - Generates a new ECDH key pair for the specified curve