SecureCommunicationFactory class

High-level factory for creating secure bidirectional communication sessions

Annotations
  • @includeInBarrelFile

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createDefaultCapabilities({required String peerId, List<KeyExchangeAlgorithm>? supportedKeyExchange, List<CryptoAlgorithm>? supportedAsymmetric, List<CryptoAlgorithm>? supportedSymmetric, KeyExchangeAlgorithm? preferredKeyExchange, CryptoAlgorithm? preferredAsymmetric, CryptoAlgorithm? preferredSymmetric}) CryptoPeerCapabilities
Creates a default peer capability set
createSessionManager() CryptoSessionManager
Creates a new session manager
initiateSecureSession({required String localPeerId, required Future<Map<String, dynamic>> sendToRemote(Map<String, dynamic>), List<CryptoAlgorithm>? supportedAsymmetric, List<CryptoAlgorithm>? supportedSymmetric, CryptoAlgorithm? preferredAsymmetric, CryptoAlgorithm? preferredSymmetric}) Future<SecureSession>
Full workflow for session initiator
respondToSecureSession({required String localPeerId, required Map<String, dynamic> initiationMessage, List<CryptoAlgorithm>? supportedAsymmetric, List<CryptoAlgorithm>? supportedSymmetric, CryptoAlgorithm? preferredAsymmetric, CryptoAlgorithm? preferredSymmetric}) Future<({Map<String, dynamic> responseMessage, SecureSession session})>
Full workflow for session responder