NegotiationResult class

Result of algorithm negotiation between two peers.

Annotations
  • @immutable

Constructors

NegotiationResult({required KeyExchangeAlgorithm keyExchange, required CryptoAlgorithm asymmetric, required CryptoAlgorithm symmetric, required String localPeerId, required String remotePeerId, required bool isInitiator})
const

Properties

asymmetric CryptoAlgorithm
final
hashCode int
The hash code for this object.
no setteroverride
isInitiator bool
final
keyExchange KeyExchangeAlgorithm
final
localPeerId String
final
remotePeerId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
symmetric CryptoAlgorithm
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override