SecureSession class
Represents an established secure session between two peers.
- Available extensions
- Annotations
-
- @immutable
Constructors
-
SecureSession({required IHandlerCipher<
ICipher> asymmetricHandler, required IHandlerCipher<ICipher> symmetricHandler, required NegotiationResult negotiationResult, required DateTime establishedAt}) -
const
Properties
-
asymmetricHandler
→ IHandlerCipher<
ICipher> -
final
- establishedAt → DateTime
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- negotiationResult → NegotiationResult
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionInfo → String
-
Available on SecureSession, provided by the SecureSessionExtensions extension
Gets session informationno setter -
final
-
symmetricHandler
→ IHandlerCipher<
ICipher> -
final
Methods
-
decryptAsymmetric(
List< int> encryptedData) → List<int> -
Available on SecureSession, provided by the SecureSessionExtensions extension
Decrypts data using the asymmetric cipher -
decryptData(
List< int> encryptedData) → List<int> -
Available on SecureSession, provided by the SecureSessionExtensions extension
Decrypts data using the negotiated symmetric cipher -
encryptAsymmetric(
List< int> data) → List<int> -
Available on SecureSession, provided by the SecureSessionExtensions extension
Encrypts data using the asymmetric cipher (for key exchange, signatures, etc.) -
encryptData(
List< int> data) → List<int> -
Available on SecureSession, provided by the SecureSessionExtensions extension
Encrypts data using the negotiated symmetric cipher -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override