SymmetricKeyUtils class

Utilities for symmetric key generation.

Annotations
  • @includeInBarrelFile

Constructors

SymmetricKeyUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generateKey({int bitLength = 256}) String
Generates a symmetric key as hex string
sha256From(String data) → Digest
Computes SHA-256 hash of the given bytes